@@ -23,6 +23,16 @@
 #include <time.h>
 #include <unistd.h>
 
+/*
+ * Condition in various optimization hacks.  You almost certainly
+ * don't want to turn any of these off; the condition symbols are
+ * present more as documentation of the program structure than
+ * anything else
+ */
+#define REDBLACK /* Use red-black trees for faster symbol loookup */
+#define TREEPACK /* Use tree-packing optimization */
+#define USE_MMAP /* Memory-mapped I/O */
+
 #include "cvstypes.h"
 /*
  * CVS_MAX_BRANCHWIDTH should match the number in the longrev test.
@@ -124,13 +134,11 @@ struct in_buffer_type {
 	int read_count;
 };
 
-#ifdef LINESTATS
 typedef struct _edit_line {
 	unsigned char *ptr;
 	size_t length;
 	int has_stringdelim;
 } editline_t;
-#endif
 
 /* Don't modify this without syncing expand_names in generate.c */
 enum expand_mode {
@@ -152,10 +160,8 @@ typedef struct _editbuffer {
 	char Gversion_number[CVS_MAX_REV_LEN];
 	struct out_buffer_type *Goutbuf;
 	struct in_buffer_type in_buffer_store;
-#ifdef LINESTATS
 	int line_len; /* temporary used for insertline */
 	int has_stringdelim;
-#endif
 	enum expand_mode Gexpand;
 	/*
 	 * Gline contains pointers to the lines in the current edit buffer
@@ -170,11 +176,7 @@ typedef struct _editbuffer {
 		node_t *next_branch;
 		node_t *node;
 		unsigned char *node_text;
-#ifdef LINESTATS
 		editline_t *line;
-#else
-		unsigned char **line;
-#endif
 		size_t gap, gapsize, linemax;
 	} stack[CVS_MAX_DEPTH / 2], *current;
 #ifdef USE_MMAP
@@ -267,7 +269,7 @@ typedef struct _revdir {
 	file_list **dirs;
 } revdir;
 
-#endif
+#endif /* TREEPACK */
 
 /*
  * Tricky polymorphism hack to reduce working set size for large repos
@@ -421,6 +423,7 @@ typedef struct _cvs_author {
 #define _noreturn __attribute__((__noreturn__))
 #define _pure __attribute__((__noreturn__))
 #define _alignof(T) __alignof__(T)
+#define _unused __attribute__((unused))
 #else
 #define _printflike(fmtarg, firstvararg) /* nothing */
 #define _alloclike(sizearg)              /* nothing */
@@ -429,6 +432,7 @@ typedef struct _cvs_author {
 #define _noreturn                        /* nothing */
 #define _pure                            /* nothing */
 #define _alignof(T) sizeof(long double)
+#define _unused /* nothing */
 #endif
 
 /* For versions of Mac OS X before Sierra */
@@ -545,13 +549,13 @@ bool cvs_is_branch_of(const cvs_number *trunk, const cvs_number *branch);
 
 int cvs_number_degree(const cvs_number *a);
 
-const cvs_number cvs_previous_rev(const cvs_number *n);
+cvs_number cvs_previous_rev(const cvs_number *n);
 
-const cvs_number cvs_master_rev(const cvs_number *n);
+cvs_number cvs_master_rev(const cvs_number *n);
 
-const cvs_number cvs_branch_head(cvs_file *f, const cvs_number *branch);
+cvs_number cvs_branch_head(cvs_file *f, const cvs_number *branch);
 
-const cvs_number cvs_branch_parent(cvs_file *f, const cvs_number *branch);
+cvs_number cvs_branch_parent(cvs_file *f, const cvs_number *branch);
 
 node_t *cvs_find_version(const cvs_file *cvs, const cvs_number *number);
 
@@ -584,9 +588,9 @@ void dump_rev_graph(git_repo *rl, const char *title);
 
 void dump_cvs_graph(forest_t *, int);
 
-const char *atom(const char *string);
+char *atom(const char *string);
 
-const cvs_number *atom_cvs_number(const cvs_number n);
+cvs_number *atom_cvs_number(const cvs_number n);
 
 unsigned long hash_cvs_number(const cvs_number *const key);
 
