@@ -92,10 +92,8 @@ static int in_buffer_getc(editbuffer_t *eb) {
 			Ginbuf(eb)->ptr -= 2;
 			--Ginbuf(eb)->read_count;
 			return EOF;
-#ifdef LINESTATS
 		} else {
 			eb->has_stringdelim = true;
-#endif
 		}
 	}
 	return c;
@@ -104,9 +102,7 @@ static int in_buffer_getc(editbuffer_t *eb) {
 static uchar *in_get_line(editbuffer_t *eb) {
 	int c;
 	uchar *ptr = Ginbuf(eb)->ptr;
-#ifdef LINESTATS
 	eb->has_stringdelim = false;
-#endif
 	c = in_buffer_getc(eb);
 	if (c == EOF) {
 		return NULL;
@@ -114,9 +110,7 @@ static uchar *in_get_line(editbuffer_t *eb) {
 	while (c != EOF && c != '\n') {
 		c = in_buffer_getc(eb);
 	}
-#ifdef LINESTATS
 	eb->line_len = Ginbuf(eb)->ptr - ptr;
-#endif
 	return ptr;
 }
 
@@ -325,7 +319,7 @@ static enum markers trymatch(char const *const string) {
 	}
 	return (Nomatch);
 }
-#ifdef LINESTATS
+
 /* Before line N, insert line L.  N is 0-origin.  */
 static void insertline(editbuffer_t *eb, const unsigned long n, uchar *l) {
 	if (n > Glinemax(eb) - Ggapsize(eb)) {
@@ -380,59 +374,6 @@ static void deletelines(editbuffer_t *eb, const unsigned long n,
 	Ggapsize(eb) += nlines;
 }
 
-#else
-/* Before line N, insert line L.  N is 0-origin.  */
-static void insertline(editbuffer_t *eb, const unsigned long n, uchar *l) {
-	if (n > Glinemax(eb) - Ggapsize(eb)) {
-		fatal_error("at %s:%s, edit script tried to insert beyond eof",
-		            eb->Gfilename, eb->Gversion_number);
-	}
-	if (!Ggapsize(eb)) {
-		if (Glinemax(eb)) {
-			Ggap(eb) = Ggapsize(eb) = Glinemax(eb);
-			Glinemax(eb) <<= 1;
-			Gline(eb) =
-			    xrealloc(Gline(eb), sizeof(uchar *) * Glinemax(eb),
-			             "insertline");
-		} else {
-			Glinemax(eb) = Ggapsize(eb) = 1024;
-			Gline(eb) = xmalloc(sizeof(uchar *) * Glinemax(eb),
-			                    "insertline");
-		}
-	}
-	if (n < Ggap(eb)) {
-		memmove(Gline(eb) + n + Ggapsize(eb), Gline(eb) + n,
-		        (Ggap(eb) - n) * sizeof(uchar *));
-	} else if (Ggap(eb) < n) {
-		memmove(Gline(eb) + Ggap(eb),
-		        Gline(eb) + Ggap(eb) + Ggapsize(eb),
-		        (n - Ggap(eb)) * sizeof(uchar *));
-	}
-	Gline(eb)[n] = l;
-	Ggap(eb) = n + 1;
-	Ggapsize(eb)--;
-}
-
-/* Delete lines N through N+NLINES-1.  N is 0-origin.  */
-static void deletelines(editbuffer_t *eb, const unsigned long n,
-                        const unsigned long nlines) {
-	unsigned long l = n + nlines;
-	if (Glinemax(eb) - Ggapsize(eb) < l || l < n) {
-		fatal_error("at %s:%s, edit script tried to delete beyond eof.",
-		            eb->Gfilename, eb->Gversion_number);
-	}
-	if (l < Ggap(eb)) {
-		memmove(Gline(eb) + l + Ggapsize(eb), Gline(eb) + l,
-		        (Ggap(eb) - l) * sizeof(uchar *));
-	} else if (Ggap(eb) < n) {
-		memmove(Gline(eb) + Ggap(eb),
-		        Gline(eb) + Ggap(eb) + Ggapsize(eb),
-		        (n - Ggap(eb)) * sizeof(uchar *));
-	}
-	Ggap(eb) = n;
-	Ggapsize(eb) += nlines;
-}
-#endif
 /* parse and return a decimal integer */
 static long parsenum(editbuffer_t *eb) {
 	int c;
@@ -859,7 +800,7 @@ uncache_exit:
 	return r + e;
 }
 
-#if USE_MMAP
+#ifdef USE_MMAP
 
 #include <fcntl.h>
 #include <sys/mman.h>
@@ -913,7 +854,8 @@ static void unload_all_text(editbuffer_t *eb) {
 	}
 }
 
-static void unload_text(editbuffer_t *eb, const cvs_text *text, uchar *data) {}
+static void unload_text(_unused editbuffer_t *eb, _unused const cvs_text *text,
+                        _unused uchar *data) {}
 #else
 static uchar *load_text(editbuffer_t *eb, const cvs_text *text) {
 	FILE *f = fopen(text->filename, "rb");
@@ -969,6 +911,7 @@ static void process_delta(editbuffer_t *eb, const node_t *const node,
 		while ((ptr = in_get_line(eb))) {
 			insertline(eb, editline++, ptr);
 		}
+	/* FALLTHROUGH */
 	/* coverity[fallthrough] */
 	case EDIT:
 		dc.dafter = dc.adprev = 0;
@@ -1003,7 +946,6 @@ static void process_delta(editbuffer_t *eb, const node_t *const node,
 }
 
 static void expandedit(editbuffer_t *eb) {
-#ifdef LINESTATS
 	editline_t *p, *lim, *l = Gline(eb);
 
 	for (p = l, lim = l + Ggap(eb); p < lim;) {
@@ -1014,18 +956,6 @@ static void expandedit(editbuffer_t *eb) {
 		in_buffer_init(eb, (*p++).ptr, false);
 		expandline(eb);
 	}
-#else
-	uchar **p, **lim, **l = Gline(eb);
-
-	for (p = l, lim = l + Ggap(eb); p < lim;) {
-		in_buffer_init(eb, *p++, false);
-		expandline(eb);
-	}
-	for (p += Ggapsize(eb), lim = l + Glinemax(eb); p < lim;) {
-		in_buffer_init(eb, *p++, false);
-		expandline(eb);
-	}
-#endif
 }
 /*
  * The FASTOUT code is a shameless micro-optimization addressing the
@@ -1082,12 +1012,11 @@ static void snapshotline(editbuffer_t *eb, register uchar *l) {
 #endif /* FASTOUT */
 }
 
-#ifdef LINESTATS
 static void snapshotline_nodelim(editbuffer_t *eb, editline_t *l) {
 	struct out_buffer_type *ob = eb->Goutbuf;
 	size_t chars_read = l->length;
 	if (chars_read != 0) {
-		while (ob->end_of_text - ob->ptr < chars_read) {
+		while ((size_t)(ob->end_of_text - ob->ptr) < chars_read) {
 			out_buffer_enlarge(eb);
 			ob = eb->Goutbuf;
 		}
@@ -1115,20 +1044,8 @@ static void snapshotedit(editbuffer_t *eb) {
 		}
 	}
 }
-#else
-static void snapshotedit(editbuffer_t *eb) {
-	uchar **p, **lim, **l = Gline(eb);
-	for (p = l, lim = l + Ggap(eb); p < lim;) {
-		snapshotline(eb, *p++);
-	}
-	for (p += Ggapsize(eb), lim = l + Glinemax(eb); p < lim;) {
-		snapshotline(eb, *p++);
-	}
-}
-#endif
 
 static void enter_branch(editbuffer_t *eb, const node_t *const node) {
-#ifdef LINESTATS
 	editline_t *p =
 	    xmalloc(sizeof(editline_t) * eb->current->linemax, "enter branch");
 	memcpy(p, eb->current->line, sizeof(editline_t) * eb->current->linemax);
@@ -1136,15 +1053,6 @@ static void enter_branch(editbuffer_t *eb, const node_t *const node) {
 	eb->current[0] = eb->current[-1];
 	eb->current->next_branch = node->sib;
 	eb->current->line = p;
-#else
-	uchar **p =
-	    xmalloc(sizeof(uchar *) * eb->current->linemax, "enter branch");
-	memcpy(p, eb->current->line, sizeof(uchar *) * eb->current->linemax);
-	++eb->current;
-	eb->current[0] = eb->current[-1];
-	eb->current->next_branch = node->sib;
-	eb->current->line = p;
-#endif
 }
 
 static node_t *generate_setup(generator_t *gen) {
@@ -1158,7 +1066,7 @@ static node_t *generate_setup(generator_t *gen) {
 		eb->Gfilename = gen->master_name;
 		eb->Gexpand = gen->expand;
 		eb->Gabspath = NULL;
-		Gline(eb) = NULL;
+		Gline(eb) = xmalloc(0, __func__);
 		Ggap(eb) = Ggapsize(eb) = Glinemax(eb) = 0;
 	}
 
