@@ -86,9 +86,11 @@ extern int yydebug;
     BRAINDAMAGED_NUMBER = 287,     /* BRAINDAMAGED_NUMBER  */
     LOGIN = 288,                   /* LOGIN  */
     TOKEN = 289,                   /* TOKEN  */
-    DATA = 290,                    /* DATA  */
-    TEXT_DATA = 291,               /* TEXT_DATA  */
-    NUMBER = 292                   /* NUMBER  */
+    SPACETOKEN = 290,              /* SPACETOKEN  */
+    TAGNAME = 291,                 /* TAGNAME  */
+    DATA = 292,                    /* DATA  */
+    TEXT_DATA = 293,               /* TEXT_DATA  */
+    NUMBER = 294                   /* NUMBER  */
   };
   typedef enum yytokentype yytoken_kind_t;
 #endif
@@ -113,7 +115,7 @@ union YYSTYPE
     cvs_branch	*branch;
     cvs_file	*file;
 
-#line 117 "gram.h"
+#line 119 "gram.h"
 
 };
 typedef union YYSTYPE YYSTYPE;
