@@ -60,10 +60,6 @@ typedef struct _analysis {
 	generator_t generator;
 } analysis_t;
 
-static cvs_master *sort_cvs_masters(cvs_master *list);
-
-static void debug_cvs_masters(cvs_master *list);
-
 static char *rectify_name(const char *raw, char *rectified, size_t rectlen) {
 	/* from master name to the name humans thought of the file by */
 	unsigned len;
@@ -181,8 +177,10 @@ static int strcommonendingwith(const char *a, const char *b, char endc) {
 }
 
 /* consume masters off the queue */
-static void *worker(void *arg) {
-	analysis_t out = {0, 0, 0};
+static void *worker(_unused void *arg) {
+	analysis_t out;
+	memset(&out, '\0',
+	       sizeof(analysis_t)); // Avoid missing-initializer warning.
 	for (;;) {
 		/* pop a master off the queue, terminating if none left */
 #ifdef THREADS
@@ -347,6 +345,7 @@ void analyze_masters(int argc, const char *argv[], import_options_t *analyzer,
 	striplen = analyzer->striplen;
 
 	forest->textsize = forest->filecount = 0;
+	forest->is_cvs = false;
 	progress_begin("Reading file list...", NO_MAX);
 	for (;;) {
 		struct stat stb;
